==> onebapp-vue-dev-0.0.10.tgz: package/lib/backend/useQuery.js <==
import gql from "graphql-tag";
import { useLazyQuery as baseQuery } from "@vue/apollo-composable";
import { computed, nextTick, ref } from "vue";
const prepareQuery = (query) => {
    return query
        .split("@pageInfo")
        .join("pageInfo { hasNextPage hasPreviousPage startCursor endCursor }");
};
export const getValueByPath = (object, path) => {
    const pathItems = path.split(".");
    return pathItems.reduce((acc, key, currentIndex) => {
        if (acc[key] == null && currentIndex > 0) {
            throw new Error(`Unable to resolve edges. Key=${key} not found in the response`);
        }
        return acc[key];
    }, object);
};
export const useQuery = (name, query, options) => {
    const doc = `query ${name} ${prepareQuery(query)}`;
    const document = gql `
    ${doc}
  `;
    const enabled = ref(true);
    const config = () => ({
        notifyOnNetworkStatusChange: true,
        fetchPolicy: options?.cacheOrLoad === true ? "cache-first" : "cache-and-network",
        nextFetchPolicy: "cache-and-network",
        // throttle: options?.throttle,
        // prefetch: false,
        enabled: enabled.value,
    });
    const { result, loading, 
    // onError,
    load, refetch, networkStatus, fetchMore, variables, error, } = baseQuery(document, options?.variables ?? null, 
    // @ts-ignore
    config);
    const loadQuery = (variables) => {
        if (networkStatus.value === 7 || networkStatus.value === 8) {
            return refetch(variables);
        }
        else {
            return load(undefined, variables);
        }
    };
    nextTick(() => loadQuery()).catch(console.error);
    return {
        isLoading: computed(() => loading.value),
        isLoadingMore: computed(() => networkStatus.value === 3),
        data: computed(() => {
            if (result.value != null && options?.select != null) {
                return getValueByPath(result.value, options.select);
            }
            return result.value;
        }),
        variables,
        error,
        load: loadQuery,
        loadMore(variables, updateQuery) {
            return fetchMore({
                variables,
                updateQuery,
            });
        },
        status: networkStatus,
        disable() {
            enabled.value = false;
        },
        enable() {
            enabled.value = true;
        },
    };
};

==> onebapp-vue-dev-0.0.14.tgz: package/lib/backend/useQuery.js <==
import gql from "graphql-tag";
import { useLazyQuery as baseQuery } from "@vue/apollo-composable";
import { computed, nextTick, ref } from "vue";
const prepareQuery = (query) => {
    return query
        .split("@pageInfo")
        .join("pageInfo { hasNextPage hasPreviousPage startCursor endCursor }");
};
export const getValueByPath = (object, path) => {
    const pathItems = path.split(".");
    return pathItems.reduce((acc, key, currentIndex) => {
        if (acc[key] == null && currentIndex > 0) {
            throw new Error(`Unable to resolve edges. Key=${key} not found in the response`);
        }
        return acc[key];
    }, object);
};
export const useQuery = (name, query, options) => {
    const doc = `query ${name} ${prepareQuery(query)}`;
    const document = gql `
    ${doc}
  `;
    const enabled = ref(options?.enabled ?? true);
    const config = () => ({
        notifyOnNetworkStatusChange: true,
        fetchPolicy: options?.cacheOrLoad === true ? "cache-first" : "cache-and-network",
        nextFetchPolicy: "cache-and-network",
        // throttle: options?.throttle,
        // prefetch: false,
        enabled: enabled.value,
    });
    const { result, loading, 
    // onError,
    load, refetch, networkStatus, fetchMore, variables, error, } = baseQuery(document, options?.variables ?? null, 
    // @ts-ignore
    config);
    const loadQuery = (variables) => {
        if (networkStatus.value === 7 || networkStatus.value === 8) {
            return refetch(variables);
        }
        else {
            return load(undefined, variables);
        }
    };
    nextTick(() => loadQuery()).catch(console.error);
    return {
        isLoading: computed(() => loading.value),
        isLoadingMore: computed(() => networkStatus.value === 3),
        data: computed(() => {
            if (result.value != null && options?.select != null) {
                return getValueByPath(result.value, options.select);
            }
            return result.value;
        }),
        variables,
        error,
        load: loadQuery,
        loadMore(variables, updateQuery) {
            return fetchMore({
                variables,
                updateQuery,
            });
        },
        status: networkStatus,
        disable() {
            enabled.value = false;
        },
        enable() {
            enabled.value = true;
        },
    };
};
